@@ -13,11 +13,4 @@ class CameraDetectMotionResult(ResultBase):
         self.hasMotion = result["hasMotion"]
         self.motionRatio = result["motionRatio"]
         self.framesProcessed = result["framesProcessed"]
-
-        if self.success is True:
-            return
-
-        if result["errorCode"] == 14:
-            self.message = self.message + ": motionDuration is bigger than Timeout"
-        else:
-            self.message = self.getMessageForErrorCode(self.message, result["errorCode"])
+        self.message = result["message"]
\ No newline at end of file
